@@ -330,12 +330,12 @@ bool AAptInterface::startAptGetSimulate()
 
 	QString runBinary = "/usr/bin/apt-get";
 	QStringList runParameters;
-	runParameters << "-qsy" << "--allow-unauthenticated";
+	runParameters << "-qsy" << "--allow-unauthenticated"
+			<< "-o" << "Dir::Etc::sourcelist=" + KAptSourceList
+			<< "-o" << "Dir::State::lists=" + KAptListDir
+			<< "-o"	<< "Dir::Etc::sourceparts=\"\"";
 	if( iSettings->qsettings()->value("enable_autoremove", true).toBool() )
-		runParameters << "--auto-remove"
-				<< "-o" << "Dir::Etc::sourcelist=" + KAptSourceList
-				<< "-o" << "Dir::State::lists=" + KAptListDir
-				<< "-o"	<< "Dir::Etc::sourceparts=\"\"";
+		runParameters << "--auto-remove";
 	runParameters << "install";
 	runParameters << iProcessPackages;
 
@@ -531,6 +531,8 @@ QString AAptInterface::finishProcessCommonErrorMessages(QByteArray& output)
 		msg = "dpkg reported errors while processing a package - see the log for details";
 	} else if( output.contains("E: Unmet dependencies") ) {
 		msg = "Some of your packages have unmet dependencies which could not be fixed. See the log for details.";
+	} else if( output.contains("E: The method driver") ) {
+		msg = "Apt failed to find a suitable method driver. One or more of your repositories might have an invalid URL.";
 	}
 
 	return msg;
