@@ -168,17 +168,37 @@ bool Package::versionCompare(QString isNewer, QString compare)
 	return false;
 }
 
-void Package::setDepends(QByteArray depends_)
+void Package::appendDepends(QByteArray line_)
 {
-	iDepends = depends_.split(',');
+	iDepends << line_.split(',');
 }
 
-void Package::setConflicts(QByteArray conflicts_)
+void Package::appendConflicts(QByteArray line_)
 {
-	iConflicts = conflicts_.split(',');
+	iConflicts << line_.split(',');
 }
 
-QStringList Package::depends()
+void Package::appendPreDepends(QByteArray line_)
+{
+	iPreDepends << line_.split(',');
+}
+
+void Package::appendProvides(QByteArray line_)
+{
+	iProvides << line_.split(',');
+}
+
+void Package::appendReplaces(QByteArray line_)
+{
+	iReplaces << line_.split(',');
+}
+
+void Package::appendBreaks(QByteArray line_)
+{
+	iBreaks << line_.split(',');
+}
+
+QStringList Package::dependsRichText()
 {
 	//qDebug() << iName;
 	//qDebug() << iDepends;
@@ -187,33 +207,85 @@ QStringList Package::depends()
 
 	for(int i=0; i<iDepends.count(); i++)
 	{
-		/*
-		QList<QByteArray> parts = iConflicts.at(i).split('|');
-		for(int j=0; j<parts.count(); j++)
-		{
-			qDebug() << parts.at(j);
-			int pos = parts.at(j).trimmed().indexOf(' ');
-			QString s;
-			if( pos==-1 )
-				s = parts.at(j).trimmed();
-			else
-				s = parts.at(j).left(pos).trimmed();
-			list << s;
-		}
-		*/
-		list << iDepends.at(i).trimmed();
+		QString s = iDepends.at(i).trimmed();
+		s.replace('<',"&lt;");
+		s.replace('>',"&gt;");
+		list << s;
 	}
 
 	return list;
 }
 
-QStringList Package::conflicts()
+QStringList Package::conflictsRichText()
 {
 	QStringList list;
 
 	for(int i=0; i<iConflicts.count(); i++)
 	{
-		list << iConflicts.at(i).trimmed();
+		QString s = iConflicts.at(i).trimmed();
+		s.replace('<',"&lt;");
+		s.replace('>',"&gt;");
+		list << s;
+	}
+
+	return list;
+}
+
+QStringList Package::preDependsRichText()
+{
+	QStringList list;
+
+	for(int i=0; i<iPreDepends.count(); i++)
+	{
+		QString s = iPreDepends.at(i).trimmed();
+		s.replace('<',"&lt;");
+		s.replace('>',"&gt;");
+		list << s;
+	}
+
+	return list;
+}
+
+QStringList Package::providesRichText()
+{
+	QStringList list;
+
+	for(int i=0; i<iProvides.count(); i++)
+	{
+		QString s = iProvides.at(i).trimmed();
+		s.replace('<',"&lt;");
+		s.replace('>',"&gt;");
+		list << s;
+	}
+
+	return list;
+}
+
+QStringList Package::replacesRichText()
+{
+	QStringList list;
+
+	for(int i=0; i<iReplaces.count(); i++)
+	{
+		QString s = iReplaces.at(i).trimmed();
+		s.replace('<',"&lt;");
+		s.replace('>',"&gt;");
+		list << s;
+	}
+
+	return list;
+}
+
+QStringList Package::breaksRichText()
+{
+	QStringList list;
+
+	for(int i=0; i<iBreaks.count(); i++)
+	{
+		QString s = iBreaks.at(i).trimmed();
+		s.replace('<',"&lt;");
+		s.replace('>',"&gt;");
+		list << s;
 	}
 
 	return list;
