@@ -130,9 +130,9 @@ void Settings::on_pushButton_picksound_clicked()
 void Settings::on_pushButton_searchOptions_clicked()
 {
 	SearchOptions s(this);
-	s.setSelections( iQSettings->value("search_pkgnames",false).toBool(),
+	s.setSelections( iQSettings->value("search_pkgnames",true).toBool(),
 					 iQSettings->value("search_displaynames",true).toBool(),
-					 iQSettings->value("search_descshort",false).toBool(),
+					 iQSettings->value("search_descshort",true).toBool(),
 					 iQSettings->value("search_desclong",false).toBool() );
 	if( s.exec() )
 	{
